@@ -17,7 +17,6 @@
 #define		DEFAULT_LOG_FILE	"time.log"
 #define		DEFAULT_CONFIG_FILE	"projects"
 
-#define VERSIONS "1.7"
 #define STRLEN 2048
 
 #define IDLE_X 5
@@ -38,7 +37,7 @@
 struct project_list
 {
   char *name ;
-  char key ;
+  int key ;
   struct project_list *next ;
   long time ;
 } *project_head=NULL ;
@@ -150,6 +149,14 @@ void read_config_file(filename)
   fclose(f) ;
 }
 
+/* there are multiple interpretations of what the "Del" key is */
+int isdelkey(int keypress)
+{
+  return((keypress==127) || \
+         (keypress==8) || \
+         (keypress==263) || \
+         (keypress==330)) ;
+}
 
 void draw_main_screen()
 {
@@ -170,12 +177,12 @@ void draw_main_screen()
       attron(A_BOLD) ;
       if(project->key!=CR)
 	{
-	  move(i,5) ;
-	  sprintf(temps,"%c",project->key) ;
-	  mvaddstr(i,5,temps) ;
+	  move(i,1) ;
+	  sprintf(temps,"    %c",project->key) ;
+	  mvaddstr(i,1,temps) ;
 	}
       else
-	mvaddstr(i,4,"CR") ;
+	mvaddstr(i,1,"   CR") ;
       attroff(A_BOLD) ;
       mvaddstr(i,7,project->name) ;
       }
@@ -201,7 +208,7 @@ void draw_main_screen()
 }
 
 
-void draw_run_options(char key)
+void draw_run_options(int key)
 {
   int i, j ;
 
@@ -211,31 +218,40 @@ void draw_run_options(char key)
   attroff(A_BOLD) ;
       
   i=num_projects+3 ;
+
+  if(key==CR)
+    {
+      attron(A_BOLD) ;
+      mvaddstr(i,1,"     ") ;
+      mvaddstr(i,7,"Press any of the category keys above to assign time") ;
+      attroff(A_BOLD) ;
+      i++ ;
+    }
   attron(A_BOLD) ;
   mvaddstr(i,1,"SPACE") ;
   attroff(A_BOLD) ;
-  mvaddstr(i,7,"Pause clock") ;
+  mvaddstr(i,7,"Pause clock                                        ") ;
   i++ ;
   if(key!=CR)
     {
       attron(A_BOLD) ;
-      mvaddstr(i,3," CR") ;
+      mvaddstr(i,1,"   CR") ;
       attroff(A_BOLD) ;
       mvaddstr(i,7,"Stop clock and optionally enter description") ;
       i++ ;
     }
   attron(A_BOLD) ;
-  mvaddstr(i,5,"+") ;
+  mvaddstr(i,1,"    +") ;
   attroff(A_BOLD) ;
   mvaddstr(i,7,"Adjust by increasing time") ;
   i++ ;
   attron(A_BOLD) ;
-  mvaddstr(i,5,"-") ;
+  mvaddstr(i,1,"    -") ;
   attroff(A_BOLD) ;
   mvaddstr(i,7,"Adjust by decreasing time") ;
   i++ ;
   attron(A_BOLD) ;
-  mvaddstr(i,3,"DEL") ;
+  mvaddstr(i,1,"  DEL") ;
   attroff(A_BOLD) ;
   mvaddstr(i,7,"Quit") ;
 
@@ -377,12 +393,12 @@ void exit_handler(int flag)
   exit(0) ;
 }
 
-char clock_on(key)
-     char key ;
+int clock_on(key)
+     int key ;
 {
   struct project_list *project ;
   int i,j,found,quit ;
-  char keypress ;
+  int keypress ;
   struct itimerval timer_value ;
   int modification,success ;
   FILE *f,*fa ;
@@ -400,10 +416,9 @@ char clock_on(key)
 	break;
       }
   
-  if(!found)  
+  if(!found) 
     for(found=0,i=2,project=project_head;!found && project!=NULL;project=project->next,i++)
-      if(tolower(project->key)==tolower(key)) /* try to find
-						 case-insensitive match */
+      if(tolower(project->key)==tolower(key)) /* try to find case-insensitive match */
 	{
 	  found=1;
 	  key=project->key;		     /* remember exact key */
@@ -546,7 +561,6 @@ char clock_on(key)
 		  attrset(A_NORMAL) ;
 		  move(i,0) ;
 		  clrtobot() ;
-		  current_project=NULL ;
 		  quit=1 ;
 		}
 	      break ;
@@ -557,8 +571,8 @@ char clock_on(key)
 	      do_resize() ;
 	      break ;;;
 	    default :
-	      beep() ;
-	      quit=1 ;
+              if(isdelkey(keypress) || (key==CR))
+                quit=1 ;  /* fall back to main loop */
 	      break ;
 	    }
 	}
@@ -630,11 +644,16 @@ char clock_on(key)
       mvaddstr(y_update,1,"  ") ;
     }
   else
-    if(key!=127 && key!=12)
+    if(!isdelkey(key) && key!=12)
       {
+        /* fprintf(stderr,"\n%c%cunknown key=%d (press control-L to refresh screen)%c%c\n",10,13,key,10,13) ; */
 	beep() ;
-	keypress=CR ;
+	keypress=ERR ;
       }
+
+  /* no current project now... */
+  current_project=NULL ;
+
   return(keypress) ;
 }
 
@@ -643,7 +662,7 @@ int main(argc,argv)
      char **argv ;
 {
   char *config_filename ;
-  char keypress ;
+  int keypress ;
   int quit,i ;
   FILE *lf ;
   time_t t ;
@@ -728,7 +747,7 @@ int main(argc,argv)
 	  do_resize() ;
 	  keypress=CR ;	  
 	}
-      if(keypress==127)
+      if(isdelkey(keypress))
 	{
 	  i=num_projects+5 ;
 	  attron(A_BLINK) ;
@@ -737,7 +756,7 @@ int main(argc,argv)
 	  attroff(A_BLINK) ;
 	  keypress=mvgetch(IDLE_Y,IDLE_X) ;
 	  mvaddstr(i,5,"                           ") ;
-	  if(keypress==127)
+          if(isdelkey(keypress))
 	    quit=1 ;
 	  keypress=CR ;
 	}
